# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.0a8

([Full Changelog](https://github.com/jupyter-ai-contrib/jupyter-server-documents/compare/v0.1.0a7...dcf8a50078d525356737c69a94ca919281c2e379))

### Enhancements made

- Cleanup and add validation to new adaptive saving strategy [#169](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/169) ([@dlqqq](https://github.com/dlqqq))
- Refactor OutputsManager to align with default Jupyter behavior [#163](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/163) ([@ellisonbg](https://github.com/ellisonbg))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-ai-contrib/jupyter-server-documents/graphs/contributors?from=2025-10-22&to=2025-10-23&type=c))

[@3coins](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3A3coins+updated%3A2025-10-22..2025-10-23&type=Issues) | [@dlqqq](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Adlqqq+updated%3A2025-10-22..2025-10-23&type=Issues) | [@ellisonbg](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Aellisonbg+updated%3A2025-10-22..2025-10-23&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.1.0a7

([Full Changelog](https://github.com/jupyter-ai-contrib/jupyter-server-documents/compare/v0.1.0a6...a1dbf46fc33e3e02fe475b3f197d1e17501d3374))

### Enhancements made

- Rename NPM package [#166](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/166) ([@dlqqq](https://github.com/dlqqq))
- Handle YChat document resets when `jupyterlab_chat` is installed [#161](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/161) ([@dlqqq](https://github.com/dlqqq))

### Bugs fixed

- Track if files are writable and disable saving if they are not. [#164](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/164) ([@ellisonbg](https://github.com/ellisonbg))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-ai-contrib/jupyter-server-documents/graphs/contributors?from=2025-10-14&to=2025-10-22&type=c))

[@3coins](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3A3coins+updated%3A2025-10-14..2025-10-22&type=Issues) | [@dlqqq](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Adlqqq+updated%3A2025-10-14..2025-10-22&type=Issues) | [@ellisonbg](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Aellisonbg+updated%3A2025-10-14..2025-10-22&type=Issues)

## 0.1.0a6

([Full Changelog](https://github.com/jupyter-ai-contrib/jupyter-server-documents/compare/10c176a76ac7595a299d4ccb4ccfb57c283c2182...bc6b60d58f569e77ab828ffe3cccff2d09a83675))

### Enhancements made

- Add optional `on_reset` argument to `YRoom` get methods [#152](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/152) ([@dlqqq](https://github.com/dlqqq))

### Bugs fixed

- Fixing lint error [#159](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/159) ([@3coins](https://github.com/3coins))
- Fix real-time output clearing for collaborative editing [#150](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/150) ([@ellisonbg](https://github.com/ellisonbg))

### Documentation improvements

- Add `CLAUDE.md` and `AGENTS.md` [#154](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/154) ([@dlqqq](https://github.com/dlqqq))

### Other merged PRs

- Increase stream limit to 200 [#149](https://github.com/jupyter-ai-contrib/jupyter-server-documents/pull/149) ([@ellisonbg](https://github.com/ellisonbg))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyter-ai-contrib/jupyter-server-documents/graphs/contributors?from=2025-07-25&to=2025-10-14&type=c))

[@3coins](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3A3coins+updated%3A2025-07-25..2025-10-14&type=Issues) | [@dlqqq](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Adlqqq+updated%3A2025-07-25..2025-10-14&type=Issues) | [@ellisonbg](https://github.com/search?q=repo%3Ajupyter-ai-contrib%2Fjupyter-server-documents+involves%3Aellisonbg+updated%3A2025-07-25..2025-10-14&type=Issues)
